@@ -382,13 +382,23 @@ template< typename CompleteMarkovModel, typename Seq  >
 void
 calculate_likelihoods( const CompleteMarkovModel & mm, const Seq & seq, likelihoods_vec_t & likelihoods ) {
 	using boost::lambda::bind;
-	using boost::ref;
 	typedef typename seqan::Iterator< const Seq >::Type it_t;
 	likelihoods.clear();
 	segmentize_by_known_bases(
 		seq,
-		bind( &calculate_known_segment_likelihoods< CompleteMarkovModel, it_t >, ref( mm ), ref( likelihoods ), boost::lambda::_1, boost::lambda::_2 ),
-		bind( &calculate_unknown_segment_likelihoods< it_t >, ref( likelihoods ), boost::lambda::_1, boost::lambda::_2 )
+		boost::lambda::bind(
+			&calculate_known_segment_likelihoods< CompleteMarkovModel, it_t >,
+			boost::ref( mm ),
+			boost::ref( likelihoods ),
+			boost::lambda::_1,
+			boost::lambda::_2
+		),
+		boost::lambda::bind(
+			&calculate_unknown_segment_likelihoods< it_t >,
+			boost::ref( likelihoods ),
+			boost::lambda::_1,
+			boost::lambda::_2
+		)
 	);
 	// make sure we calculated the right number of likelihoods
 	MYRRH_ASSERT( likelihoods.size() == seqan::length( seq ) );
